#
# spec file for package python-CairoSVG
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-CairoSVG
Version:        2.4.2
Release:        bp153.1.21
Summary:        A Python SVG converter based on Cairo
License:        LGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            http://www.cairosvg.org/
Source:         https://files.pythonhosted.org/packages/source/C/CairoSVG/CairoSVG-%{version}.tar.gz
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module cairocffi}
BuildRequires:  %{python_module cssselect2}
BuildRequires:  %{python_module defusedxml}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tinycss2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow
Requires:       python-cairocffi
Requires:       python-cssselect2
Requires:       python-defusedxml
Requires:       python-tinycss2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
CairoSVG is a SVG converter based on Cairo. It can export SVG files to PDF,
PostScript and PNG files.

For further information, please visit the CairoSVG website, http://www.cairosvg.org.

%prep
%setup -q -n CairoSVG-%{version}
# remove needless pytest dependencies
sed -i setup.cfg \
    -e '/pytest-runner/d' \
    -e '/--flake8/d' \
    -e '/--isort/d'

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}/%{_bindir}/cairosvg

%check
%pytest

%post
%python_install_alternative cairosvg

%postun
%python_uninstall_alternative cairosvg

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/cairosvg
%{python_sitelib}/*

%changelog
* Tue Sep 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.2:
  * Fix race condition in tests
  * Fix scale for images with no viewBox
* Mon Sep  9 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.1:
  * Fix the scale parameter
  * Allow href attributes with no namespace
  * Fix the tree root detection
* Tue Jun  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.0:
  * Fix aspect and position when resizing root SVG tag
  * Follow aspect and position hints when using forced output size
* Mon Apr 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.3.1:
  * Fix relative paths on Windows
* Wed Feb 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.3.0:
  * Drop Python 3.4 support
  * Make text selectable on generated PDF files
  * Don't inherit dx and dy attributes
  * Fix support of alignment-baseline="hanging"
  * Fix backslashes in docstrings and comments
  * Fix local anchors with files with no given URL
  * Close VERSION's file descriptor
  * Fix T commands used with previous relative commands in paths
  * Use real functions for svg2* commands, improving IDE integration
  * Handle image-rendering property
  * Fix crash with some text samples
  * Fix position of embedded svg tags with a viewbox not at position (0, 0)
  * Add output-width and output-height options
  * Handle references to inner document tags defined after the anchor
  * Fix offsets for texts on paths
- Run tests manualy reducing the test dependencies a bit
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of description.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May  3 2018 toddrme2178@gmail.com
- Update to version 2.1.3
  * Fix T commands following q or t in paths
- Update to version 2.1.2
  * Fix font-size
- Update to version 2.1.1
  * Use http://www.w3.org/2000/svg as default namespace
- Update to version 2.1.0
  * Use cssselect2 and tinycss2 instead of cssselect and tinycss
  * Don't require lxml anymore
  * Rely on defusedxml to detect unsafe SVG files
* Tue Aug 22 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Split Python2 version into separate package due to upstream
  dropping Python2 support.
- Update to Version 2.0.3
  * Add ``python_requires`` in ``setup.py``
- Update to Version 2.0.2
  * Handle ``text-align`` in textPath tags
  * Test with Python 3.6
- Update to Version 2.0.1
  * Don't crash on relative refs with no input URL
- Update to Version 2.0.0
  * Drop Python 2 support
  * Drop pycairo support
  * Rely on cairocffi, lxml, cssselect, pillow and tinycss
  * Fix markers
  * Fix URL/id handling
  * Use bounding boxes for gradients
  * Split deployment and development tests
  * Add a scale option
  * Add a parent size option
  * Test with Travis
- Update to Version 1.0.22
  * Fix crash when lxml is not installed
- Update to Version 1.0.21
  * *WARNING:** this is a security update.
  CairoSVG was vulnerable to XML eXternal Entity (XXE) attacks, this release
  fixes this vulnerability by not resolving the XML entities anymore.
  The ``--unsafe`` option has been added to force the resolution of XML
  entities. Obviously, this option is not safe and should only be used with
  trusted SVG files.
- Update to Version 1.0.20
  * Allow the user to give parent size
- Update to Version 1.0.19
  * Drastically improve the performance of ``Node()``
- Update to Version 1.0.18
  * Use cairo groups to apply filters
- Update to Version 1.0.17
  * Fix scale and position of markers
- Update to Version 1.0.16
  * Support the text-rendering property
- Update to Version 1.0.15
  * Use xMidYMid as default preserveAspectRatio value
- Update to Version 1.0.14
  * Support the shape-rendering property
- Update to Version 1.0.13
  * Fix end markers
- Update to Version 1.0.12
  * Don't crash when paths with markers end with a move_to action
- Update to Version 1.0.11
  * Allow commas in viewboxes
- Update to Version 1.0.10
  * Allow quotes around font names
- Update to Version 1.0.9
  * Don't crash when gradients are applied to paths
- Update to Version 1.0.8
  * Don't create an atomic layer for transparent tags with no children
- Update to Version 1.0.7
  * Fix scaling with negative viewBox origin
  * Automatically detect size and position of circles and ellipses for gradients
- Update to Version 1.0.6
  * Fall back to pycairo if cairocffi is unable to find the cairo library
- Update to Version 1.0.5
  * Don't inherit clip* and overflow properties
  * Don't transform the root svg tag according to the PreservAspectRatio attribute
  * Add simple support for alignment-baseline
  * Add cairocffi into setup.py deps
- Update to Version 1.0.4
  * Clear relative coordinates when absolute coordinates are set in tspan tags
- Update to Version 1.0.3
  * Fix clips and viewboxes
  * Don't draw an empty image when locale is not set
- Update to Version 1.0.2
  * Don't crash when locale is not set
  * Get the xml_tree from the root parent when creating nodes from string
- Update to Version 1.0.1
  * Don't crash when svg tag has no width or height
- Update to Version 1.0
  * CairoCFFI support
  * Support of more external CSS stylesheets
  * Handle more filters
  * Use pillow instead of pystacia
  * Fix a lot of bugs with text (whitespaces, text on a path, etc.)
  * Inherit attributes in ``use`` tags
  * Cache trees for ``use`` tags
  * Handle conditional structures
* Wed Jan 16 2013 alexandre@exatati.com.br
- Initial version (0.5) for openSUSE.
